##  Overview
The meta model in SAP LeanIX is a conceptual model that defines the structure, relationships, and semantics of fact sheets, providing a framework for documenting and managing enterprise architecture. As an admin, you can adjust the configuration of the meta model for your workspace in the Meta Model Configuration section of the administration area. To learn more about the meta model and specific fact sheets included in it, see [Meta Model](https://help.sap.com/docs/leanix/ea/meta-model?locale=en-US&state=PRODUCTION&version=CLOUD "Get an overview of the SAP LeanIX meta model and its key concepts.").
Fact sheets are the primary objects in the meta model that hold information about the various elements in your IT landscape. You can customize them to suit your organization's specific data requirements. If needed, you can also create custom fact sheet types and subtypes.
This guide explains how to configure a fact sheet and provides an overview of fact sheet settings. To learn how to configure specific settings, such as relations, permissions, conditional attributes, and more, browse relevant topics in this section.
![Meta Model Configuration Section in the Administration Area](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274a53497a4410149bfce59efe4376c4_LowRes.png)
Meta Model Configuration Section in the Administration Area
